==> sniffles_0.0.1+ds-1.debian.tar.xz: debian/sniffles.1.md <==
% SNIFFLES(1) 0.0.1
% Fritz Sedlazeck <fritz.sedlazech@gmail.com>
%

# NAME

sniffles - structural variation caller for third-generation sequencing data

# SYNOPSIS

**sniffles**  -m *string* [-s *int*] [--max_num_splits *int*] [-q *int*]
               [-l *int*] [-v *string*] [--bede *string*] [-c *int*] [-t
               *int*] [-d *int*] [-n *int*] [--use_MD_Cigar] [--]
               [--version] [-h]

**sniffles** **-m** *reads.bam* **-v** *calls.vcf*

# DESCRIPTION
Sniffles is a structural variation caller using third generation sequencing (PacBio or Oxford Nanopore). It detects all types of SVs using evidence from split-read alignments, high-mismatch regions, and coverage analysis. Please note the current version of Sniffles requires output from BWA-MEM with the optional SAM attributes enabled!

# OPTIONS

   -m *string*,  --mapped_reads *string*
:     (required)  Bam File

   -s *int*,  --min_support *int*
:     Minimum number of reads that support a SV. Default: 10

   --max_num_splits *int*
:     Maximum number of splits per read to be still taken into account.
     Default: 4

   -q *int*,  --minmapping_qual *int*
:     Minimum Mapping Quality. Default: 20

   -l *int*,  --min_length *int*
:     Minimum length of SV to be reported. Default:0

   -v *string*,  --vcf *string*
:     VCF output file name

   --bede *string*
:     Simplified format of bede Format.

   -c *int*,  --min_cigar_event *int*
:     Minimum Cigar Event (e.g. Insertion, deletion) to take into account.
     Default:50 

   -t *int*,  --threads *int*
:     Number of threads to use. Default: 3

   -d *int*,  --max_distance *int*
:     Maximum distance to group SV together. Default: 1kb

   -n *int*,  --num_reads_report *int*
:     Report up to N reads that support the SV. Default: 0

   --use_MD_Cigar
:     Enables Sniffles to use the alignment information to screen for
     suspicious regions.

   --,  --ignore_rest
:     Ignores the rest of the labeled arguments following this flag.

   --version
:     Displays version information and exits.

   -h,  --help
:     Displays usage information and exits.

# BUGS

If you experience problems or have suggestions please contact: fritz.sedlazeck@gmail.com

# SEE ALSO

**bwa**(1)

==> sniffles_1.0.2+ds-1.debian.tar.xz: debian/sniffles.1.md <==
% SNIFFLES(1) 1.0.0
% Fritz Sedlazeck <fritz.sedlazech@gmail.com>
%

# NAME

sniffles - structural variation caller for third-generation sequencing data

# SYNOPSIS

**sniffles**  -m *string* [-s *int*] [--max_num_splits *int*] [-q *int*]
               [-l *int*] [-v *string*] [--bede *string*] [-c *int*] [-t
               *int*] [-d *int*] [-n *int*] [--]
               [--version] [-h]

**sniffles** **-m** *reads.bam* **-v** *calls.vcf*

# DESCRIPTION
Sniffles is a structural variation caller using third generation sequencing (PacBio or Oxford Nanopore). It detects all types of SVs using evidence from split-read alignments, high-mismatch regions, and coverage analysis. Please note the current version of Sniffles requires output from BWA-MEM with the optional SAM attributes enabled!

# OPTIONS

   -m *string*,  --mapped_reads *string*
:     (required)  Bam File

   -s *int*,  --min_support *int*
:     Minimum number of reads that support a SV. Default: 10

   --max_num_splits *int*
:     Maximum number of splits per read to be still taken into account.
     Default: 4

   -q *int*,  --minmapping_qual *int*
:     Minimum Mapping Quality. Default: 20

   -l *int*,  --min_length *int*
:     Minimum length of SV to be reported. Default:0

   -v *string*,  --vcf *string*
:     VCF output file name

   --bede *string*
:     Simplified format of bede Format.

   -c *int*,  --min_cigar_event *int*
:     Minimum Cigar Event (e.g. Insertion, deletion) to take into account.
     Default:50 

   -t *int*,  --threads *int*
:     Number of threads to use. Default: 3

   -d *int*,  --max_distance *int*
:     Maximum distance to group SV together. Default: 1kb

   -n *int*,  --num_reads_report *int*
:     Report up to N reads that support the SV. Default: 0

   --,  --ignore_rest
:     Ignores the rest of the labeled arguments following this flag.

   --version
:     Displays version information and exits.

   -h,  --help
:     Displays usage information and exits.

# BUGS

If you experience problems or have suggestions please contact: fritz.sedlazeck@gmail.com

# SEE ALSO

**bwa**(1)
